@@ -25,6 +25,7 @@ from ...types.chat import (
     completion_create_params,
     ChatCompletionStreamOptionsParam,
     ChatCompletionToolParam,
+    ChatCompletionToolChoiceOptionParam
 )
 
 __all__ = ["Completions", "AsyncCompletions"]
@@ -47,7 +48,6 @@ class Completions(SyncAPIResource):
         model: str,
         frequency_penalty: Optional[float] | None = None,
         function_call: completion_create_params.FunctionCall | None = None,
-        functions: Iterable[completion_create_params.Function] | None = None,
         logit_bias: Optional[Dict[str, int]] | None = None,
         logprobs: Optional[bool] | None = None,
         max_tokens: Optional[int] | None = None,
@@ -59,6 +59,10 @@ class Completions(SyncAPIResource):
         tools: Iterable[ChatCompletionToolParam] | None = None,
         top_logprobs: Optional[int] | None = None,
         top_p: Optional[float] | None = None,
+        repetition_penalty: Optional[float] | None = None,
+        n: Optional[int] | None = None,
+        tool_choice: ChatCompletionToolChoiceOptionParam | None = None,
+        response_format: completion_create_params.ResponseFormat | None = None,
         user: str | None = None,
         extra_headers: Headers | None = None,
         extra_query: Query | None = None,
@@ -72,7 +76,6 @@ class Completions(SyncAPIResource):
                 "model": model,
                 "frequency_penalty": frequency_penalty,
                 "function_call": function_call,
-                "functions": functions,
                 "logit_bias": logit_bias,
                 "logprobs": logprobs,
                 "max_tokens": max_tokens,
@@ -85,6 +88,10 @@ class Completions(SyncAPIResource):
                 "top_logprobs": top_logprobs,
                 "top_p": top_p,
                 "user": user,
+                "repetition_penalty": repetition_penalty,
+                "n": n,
+                "tool_choice": tool_choice,
+                "response_format": response_format,
             },
             options=make_request_options(
                 extra_headers=extra_headers,
@@ -115,7 +122,6 @@ class AsyncCompletions(AsyncAPIResource):
         model: str,
         frequency_penalty: Optional[float] | None = None,
         function_call: completion_create_params.FunctionCall | None = None,
-        functions: Iterable[completion_create_params.Function] | None = None,
         logit_bias: Optional[Dict[str, int]] | None = None,
         logprobs: Optional[bool] | None = None,
         max_tokens: Optional[int] | None = None,
@@ -128,6 +134,10 @@ class AsyncCompletions(AsyncAPIResource):
         top_logprobs: Optional[int] | None = None,
         top_p: Optional[float] | None = None,
         user: str | None = None,
+        repetition_penalty: Optional[float] | None = None,
+        n: Optional[int] | None = None,
+        tool_choice: ChatCompletionToolChoiceOptionParam | None = None,
+        response_format: completion_create_params.ResponseFormat | None = None,
         extra_headers: Headers | None = None,
         extra_query: Query | None = None,
         extra_body: Body | None = None,
@@ -140,7 +150,6 @@ class AsyncCompletions(AsyncAPIResource):
                 "model": model,
                 "frequency_penalty": frequency_penalty,
                 "function_call": function_call,
-                "functions": functions,
                 "logit_bias": logit_bias,
                 "logprobs": logprobs,
                 "max_tokens": max_tokens,
@@ -153,6 +162,10 @@ class AsyncCompletions(AsyncAPIResource):
                 "top_logprobs": top_logprobs,
                 "top_p": top_p,
                 "user": user,
+                "repetition_penalty": repetition_penalty,
+                "n": n,
+                "tool_choice": tool_choice,
+                "response_format": response_format,
             },
             options=make_request_options(
                 extra_headers=extra_headers,
